@@ -96,6 +96,14 @@ class SqliteDocumentPersistence(object):
         self.cursor.execute("pragma temp_store = memory")
         self.cursor.execute("pragma mmap_size = 30000000000")
 
+        try:
+            # We need to populate node_type_id_by_name
+            for n_type in self.cursor.execute("select id,name from n_type"):
+                self.node_types[n_type[0]] = n_type[1]
+                self.node_type_id_by_name[n_type[1]] = n_type[0]
+        except:
+            pass
+
     def create_in_memory_database(self, disk_db_path: str):
         # Connect to the in-memory database
         mem_conn = sqlite3.connect(':memory:')
@@ -1088,6 +1096,26 @@ class SqliteDocumentPersistence(object):
 
         return content_nodes
 
+    def get_nodes_by_type(self, node_type):
+        """
+        Retrieves nodes of a given type from the document.
+
+        Args:
+            node_type (str): The type of the nodes to be retrieved.
+
+        Returns:
+            list: A list of nodes of the given type.
+        """
+        content_nodes = []
+
+        node_type_id = self.node_type_id_by_name.get(node_type)
+
+        query = "select id, pid, nt, idx from cn where nt = ? order by idx"
+        for content_node in self.cursor.execute(query, [node_type_id]).fetchall():
+            content_nodes.append(self.__build_node(content_node))
+
+        return content_nodes
+
 
 class SimpleObjectCache(object):
     """
@@ -1226,6 +1254,18 @@ class PersistenceManager(object):
             document, filename, delete_on_close, inmemory=inmemory
         )
 
+    def get_nodes_by_type(self, node_type: str) -> List[ContentNode]:
+        """
+        Retrieves all nodes of a given type from the underlying persistence layer.
+
+        Args:
+            node_type (str): The type of the nodes to be retrieved.
+
+        Returns:
+            List[ContentNode]: A list of all nodes of the given type.
+        """
+        return self._underlying_persistence.get_nodes_by_type(node_type)
+
     def get_node_by_uuid(self, uuid: int) -> ContentNode:
         """
         Retrieves a node by its uuid.
@@ -1474,6 +1514,14 @@ class PersistenceManager(object):
         if node.index is None:
             node.index = 0
 
+        # Check if the node exists in the DB
+        if node.uuid is None:
+            node.uuid = self.node_cache.next_id
+            self.node_cache.next_id += 1
+
+        if self._underlying_persistence.get_node(node.uuid) is None:
+            self._underlying_persistence.add_content_node(node, parent)
+
         if parent:
             node._parent_uuid = parent.uuid
             self.node_cache.add_obj(parent)
