@@ -236,7 +236,13 @@ class PipelineStep:
         self, step, name=None, options=None, attach_source=False, step_type="ACTION", conditional=None
     ):
         if options is None:
-            options = {}
+            try:
+                if 'options' in step:
+                    options = step['options']
+                else:
+                    options = {}
+            except:
+                options = {}
         self.step = step
         self.name = name
         self.options = options
@@ -254,7 +260,10 @@ class PipelineStep:
             from kodexa import RemoteStep
 
             self.step = RemoteStep(
-                step, step_type=step_type, options=options, attach_source=attach_source
+                step, step_type=step_type,
+                options=options,
+                attach_source=attach_source,
+                conditional=conditional
             )
         else:
             logger.info(f"Adding new step {type(step)} to pipeline")
@@ -274,7 +283,7 @@ class PipelineStep:
                     "You can not yet deploy a pipeline with a class instance style step"
                 )
             if isinstance(self.step, str):
-                return {"ref": self.step, "options": self.options}
+                return {"ref": self.step, "options": self.options, "conditional": self.conditional}
             if callable(self.step):
                 metadata = {
                     "function": self.step.__name__,
@@ -491,12 +500,18 @@ class Pipeline:
             options (optional): Options to be passed to the step if it is a simplified remote action. Defaults to None.
             attach_source (bool, optional): If step is simplified remote action this determines if we need to add the source. Defaults to False.
             step_type (str, optional): The type of step to add, can either be an ACTION or MODEL. Defaults to 'ACTION'.
-
+            conditional (str, optional): The conditional to use for the step. Defaults to None.
         Returns:
             Pipeline: The instance of the pipeline.
         """
         if options is None:
-            options = {}
+            try:
+                if 'options' in step:
+                    options = step['options']
+                else:
+                    options = {}
+            except:
+                options = {}
         self.steps.append(
             PipelineStep(
                 step=step,
